@@ -3,13 +3,6 @@
 
 #include <Rcpp.h>
 #include <vector>
-#include <cmath>
-#include <cstdlib>
-#include <algorithm>
-#include <utility>
-
-// [[Rcpp::interfaces(r, cpp)]]
-// [[Rcpp::plugins(cpp11)]]
 
 std::vector<int> generate_primes_(int min, int max);
 std::vector<int> generate_n_primes(int n);
@@ -22,7 +15,7 @@ int prime_count(int n, bool upper_bound);
 int nth_prime_estimate(int n, bool upper_bound);
 Rcpp::List k_tuple(int min, int max, std::vector<int> tuple);
 Rcpp::List sexy_prime_triplets(int min, int max);
-//Rcpp::List prime_factors(const Rcpp::IntegerVector& x);
+Rcpp::List prime_factors(const Rcpp::IntegerVector& x);
 int gcd_(int m, int n);
 int scm_(int m, int n);
 int Rgcd_(const Rcpp::IntegerVector& x);
